pub fn verify_auth(
auth_config: Option<&AuthConfig>,
headers: &HeaderMap,
body: &[u8],
) -> AuthResultExpand description
Verify authentication for a webhook request
If both signature and bearer token are configured, both must pass.
pub fn verify_auth(
auth_config: Option<&AuthConfig>,
headers: &HeaderMap,
body: &[u8],
) -> AuthResultVerify authentication for a webhook request
If both signature and bearer token are configured, both must pass.