pub struct HttpSourceConfig {
pub host: String,
pub port: u16,
pub endpoint: Option<String>,
pub timeout_ms: u64,
pub adaptive_max_batch_size: Option<usize>,
pub adaptive_min_batch_size: Option<usize>,
pub adaptive_max_wait_ms: Option<u64>,
pub adaptive_min_wait_ms: Option<u64>,
pub adaptive_window_secs: Option<u64>,
pub adaptive_enabled: Option<bool>,
pub webhooks: Option<WebhookConfig>,
pub durability: Option<DurabilityConfig>,
}Expand description
HTTP source configuration
This config only contains HTTP-specific settings. Bootstrap provider configuration (database, user, password, tables, etc.) should be provided via the source’s generic properties map.
Fields
host: StringHTTP host
port: u16HTTP port
endpoint: Option<String>Optional endpoint path
timeout_ms: u64Request timeout in milliseconds
adaptive_max_batch_size: Option<usize>Adaptive batching: maximum batch size
adaptive_min_batch_size: Option<usize>Adaptive batching: minimum batch size
adaptive_max_wait_ms: Option<u64>Adaptive batching: maximum wait time in milliseconds
adaptive_min_wait_ms: Option<u64>Adaptive batching: minimum wait time in milliseconds
adaptive_window_secs: Option<u64>Adaptive batching: throughput window in seconds
adaptive_enabled: Option<bool>Whether adaptive batching is enabled
webhooks: Option<WebhookConfig>Webhook configuration (enables webhook mode when present)
durability: Option<DurabilityConfig>Optional WAL durability configuration.
When present and enabled, the source persists incoming events to a local Write-Ahead Log before acknowledging the caller, enabling crash recovery and replay for persistent queries.
Implementations
Sourceimpl HttpSourceConfig
Returns true if webhook mode is enabled
impl HttpSourceConfig
Returns true if webhook mode is enabled
Sourcepub fn is_webhook_mode(&self) -> bool
pub fn is_webhook_mode(&self) -> bool
Check if webhook mode is enabled